==> wildfly-dist-10.0.0.Final-src.zip: wildfly-10.0.0.Final-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/environment/XMLInterceptorB.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.ejb.interceptor.environment;

import javax.interceptor.InvocationContext;

import org.jboss.logging.Logger;

/**
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class XMLInterceptorB {
    private static final Logger log = Logger.getLogger(XMLInterceptorB.class);

    MySession2RemoteB session2;

    public Object intercept(InvocationContext ctx) throws Exception {
        log.info("Calling XMLInterceptorB...");
        session2.doitSession();
        log.info("Calling XMLInterceptorB - after doit");
        return false;
    }

}

==> wildfly-dist-27.0.0.Final-src.zip: wildfly-27.0.0.Final-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/environment/XMLInterceptorB.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.ejb.interceptor.environment;

import jakarta.interceptor.InvocationContext;

import org.jboss.logging.Logger;

/**
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class XMLInterceptorB {
    private static final Logger log = Logger.getLogger(XMLInterceptorB.class);

    MySession2RemoteB session2;

    public Object intercept(InvocationContext ctx) throws Exception {
        log.trace("Calling XMLInterceptorB...");
        session2.doitSession();
        log.trace("Calling XMLInterceptorB - after doit");
        return false;
    }

}
